@@ -2,6 +2,8 @@ import argparse
 import textwrap
 from importlib import import_module
 
+from mgetool.tool import tt
+
 title = """
 ---------------------------
 |     Featurebox CLI      |
@@ -48,7 +50,6 @@ def main(prog='featurebox', description='featurebox command line tool.', args=No
                            nargs='?',
                            metavar='sub-command',
                            help='Provide help for sub-command.')
-
     functions = {}
     parsers = {}
     for command, module_name in commands:
@@ -75,7 +76,6 @@ def main(prog='featurebox', description='featurebox command line tool.', args=No
         parsers[command] = subparser
 
     args = parser.parse_args(args)
-
     if args.command == 'help':
 
         if args.helpcommand is None:
@@ -106,6 +106,7 @@ def main(prog='featurebox', description='featurebox command line tool.', args=No
                 parser.error(l1 + l2)
 
 
+
 class Formatter(argparse.HelpFormatter):
     """Improved help formatter."""
 
@@ -130,3 +131,7 @@ class Formatter(argparse.HelpFormatter):
                 out += textwrap.fill(block, width=width) + '\n'
             out += '\n'
         return out[:-1]
+
+
+if __name__ =="__main__":
+    main(args='h')
\ No newline at end of file
