@@ -2,7 +2,7 @@
 all with ``calculate`` method.
 """
 import copy
-from typing import Dict, Tuple
+from typing import Dict, Tuple, List
 
 import numpy as np
 from pymatgen.core import Structure, Molecule
@@ -17,7 +17,11 @@ from featurebox.featurizers.descriptors.behlerparrinello import BehlerParrinello
 from featurebox.featurizers.descriptors.wACSF import wACSF
 from featurebox.featurizers.envir._get_radius_in_spheres import get_radius_in_spheres
 from featurebox.utils.general import aaa
-from featurebox.utils.look_json import mark_classes
+
+
+def mark_classes(classes: List):
+    return {i.__name__: i for i in classes}
+
 
 DesDict = mark_classes([
     ACSF,
@@ -30,9 +34,6 @@ DesDict = mark_classes([
     wACSF,
 ])
 
-for i, j in DesDict.items():
-    locals()[i] = j
-
 
 def get_strategy2_in_spheres(structure, nn_strategy, cutoff, numerical_tol=None, cutoff_name="cutoff", pbc=True):
     _ = numerical_tol
@@ -51,8 +52,8 @@ def get_strategy2_in_spheres(structure, nn_strategy, cutoff, numerical_tol=None,
 
     a1, a2, a3, a4, _ = get_radius_in_spheres(structure, nn_strategy=None, cutoff=cutoff,
                                               numerical_tol=numerical_tol,
-                                           pbc=pbc,
-                                           )
+                                              pbc=pbc,
+                                              )
 
     return a1, a2, a3, a4, b5
 
@@ -76,7 +77,7 @@ def get_5_result(d: Dict, **kwargs) -> Tuple[np.ndarray, np.ndarray, np.ndarray,
         center_prop: np.ndarray 1d(N,l_c).\n
 
     """
-    center= d["x"]
+    center = d["x"]
     atom_len = center.shape[0]
 
     center_indices = np.array(range(atom_len))
