@@ -7,8 +7,12 @@ The costumed as following:
 """
 import copy
 from typing import Dict, List, Tuple
-
+from pymatgen.core import Element
+from pymatgen.core import Molecule
+from pymatgen.core.structure import Structure
+from featurebox.utils.predefined_typing import StructureOrMolecule
 import numpy as np
+
 from pymatgen.analysis.local_env import (
     NearNeighbors,
     VoronoiNN,
@@ -20,12 +24,10 @@ from pymatgen.analysis.local_env import (
     EconNN,
     CrystalNN,
 )
-from pymatgen.core import Element
-from pymatgen.core import Molecule
-from pymatgen.core.structure import Structure
 
-from featurebox.utils.look_json import mark_classes
-from featurebox.utils.predefined_typing import StructureOrMolecule
+
+def mark_classes(classes: List):
+    return {i.__name__: i for i in classes}
 
 
 def _is_in_targets(site, targets):
@@ -194,14 +196,11 @@ NNDict = mark_classes([
     # Please follow the instructions at https://github.com/aoterodelaroza/critic2.
 ])
 
-for i, j in NNDict.items():
-    locals()[i] = j
-
 
 def get_strategy1_in_spheres(structure: StructureOrMolecule, nn_strategy: NearNeighbors,
-                            cutoff: float = 5.0, numerical_tol: float = 1e-8,
-                            pbc=True,
-                            ) -> Tuple[np.ndarray, np.ndarray, np.ndarray, np.ndarray, np.ndarray]:
+                             cutoff: float = 5.0, numerical_tol: float = 1e-8,
+                             pbc=True,
+                             ) -> Tuple[np.ndarray, np.ndarray, np.ndarray, np.ndarray, np.ndarray]:
     nn_strategy_ = copy.copy(nn_strategy)
 
     nn_strategy_.cutoff = cutoff
@@ -240,4 +239,4 @@ def get_strategy1_in_spheres(structure: StructureOrMolecule, nn_strategy: NearNe
 
     return np.array(center_indices)[exclude_self], np.array(neighbor_indices)[exclude_self], \
            np.array(images)[exclude_self], np.array(distances)[exclude_self], \
-           np.array(center_prop)
\ No newline at end of file
+           np.array(center_prop)
